==> guikachu-1.2.2.tar.gz: guikachu-1.2.2/src/form-editor/button-prop.h <==
//$Id: button-prop.h,v 1.8 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_BUTTON_PROP_H
#define GUIKACHU_FORM_EDITOR_BUTTON_PROP_H

namespace Guikachu
{
    namespace GUI
    {
	namespace FormEditor
	{
	    class ButtonProperties;
	}
    }
}

#include "button.h"

#include <sigc++/object.h>
#include <gtk--/optionmenu.h>

namespace Guikachu
{
    namespace GUI
    {
	namespace FormEditor
	{
	    class ButtonProperties: public SigC::Object
	    {
		Widgets::Button   *res;
		
		/* Property editor */
		Gtk::Widget       *property_editor;
		
		Gtk::OptionMenu   *frame_combo;
	    public:
		ButtonProperties (Widgets::Button *res);
		~ButtonProperties ();
		Gtk::Widget *get_editor ();

	    private:
		void update ();
		bool update_block;
		
		void frame_menu_cb (Widgets::ButtonFrameType frame_type);
	    };
	}
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_BUTTON_PROP_H */

==> guikachu-1.3.2.tar.gz: guikachu-1.3.2/src/form-editor/button-prop.h <==
//$Id: button-prop.h,v 1.9 2002/06/09 21:39:44 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_BUTTON_PROP_H
#define GUIKACHU_FORM_EDITOR_BUTTON_PROP_H

namespace Guikachu
{
    namespace GUI
    {
	namespace FormEditor
	{
	    class ButtonProperties;
	}
    }
}

#include "button.h"

#include <sigc++/object.h>
#include <gtk--/optionmenu.h>

namespace Guikachu
{
    namespace GUI
    {
	namespace FormEditor
	{
	    class ButtonProperties: public SigC::Object
	    {
		Widgets::Button   *res;
		
		/* Property editor */
		Gtk::Widget       *property_editor;
		
		Gtk::OptionMenu   *frame_combo;
	    public:
		ButtonProperties (Widgets::Button *res);
		~ButtonProperties ();
		Gtk::Widget *get_editor ();

	    private:
		void update ();
		bool update_block;
		
		void frame_menu_cb (Widgets::Button::FrameType frame_type);
	    };
	}
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_BUTTON_PROP_H */
